package be.iminds.ilabt.jfed.util;

import javax.inject.Singleton;
import java.io.IOException;
import java.util.Properties;

/**
 * JFedVersionInfo: Fetches info about the jFed Version
 */
@Singleton
public class JFedVersionInfo {
    private static final String VERSION_PROPERTIES_FILE = "/version.properties";
    private static final String PROP_VERSION = "version";

    private static final String PROP_GIT_COMMIT = "build.git_commit";
    private static final String PROP_GIT_BRANCH = "build.git_branch";

    private static final String PROP_BUILD_JENKINS = "build.jenkins_build";

    private final String version;
    private final String jenkinsBuild;
    private final String gitCommit;
    private final String gitBranch;

    private final String fullVersionString;

    public JFedVersionInfo() {
        Properties prop = new Properties();
        /* Load the version-properties file

          This file is filled in during the build. See version filtering the maven pom.xml files:

              <resources>
                  <resource>
                      <directory>src/main/resources</directory>
                      <filtering>true</filtering>
                  </resource>
              </resources>

         */
        try {
            prop.load(getClass().getResourceAsStream(VERSION_PROPERTIES_FILE));
        } catch (IOException e) {
            throw new RuntimeException("Something went wrong fetching the jFed version: " + e.getMessage(), e);

        }

        this.version = prop.getProperty(PROP_VERSION, "Unknown");
        jenkinsBuild = prop.getProperty(PROP_BUILD_JENKINS);
        gitCommit = prop.getProperty(PROP_GIT_COMMIT);
        gitBranch = prop.getProperty(PROP_GIT_BRANCH);

        String fullVersionStr = this.version;
        if (jenkinsBuild != null && !jenkinsBuild.isEmpty())
            fullVersionStr += "  - build #"+jenkinsBuild;
        if (gitCommit != null && !gitCommit.isEmpty())
            fullVersionStr += "  - git commit #"+gitCommit;
        fullVersionStr+=" on "+gitBranch;

        fullVersionString = fullVersionStr.toString();
    }

    public String getVersion() {
        return version;
    }

    public String getJenkinsBuild() {
        return jenkinsBuild;
    }

    public String getGitCommit() {
        return gitCommit;
    }

    public String getGitBranch() {
        return gitBranch;
    }

    public String getFullVersionString() {
        return fullVersionString;
    }

    public static String getEnvironmentString() {
        return "" + System.getProperty("os.name") +
                " " + System.getProperty("os.version") +
                " " + System.getProperty("os.arch") +
                " - Java " + System.getProperty("java.version") +
                " (" + System.getProperty("java.vendor") + ")";
    }
}
